# rcmt

With rcmt you can

- create, modify or delete files across many repositories.
- merge global settings with user-configured settings in repositories.
- write your own tooling to manipulate files in repositories.

Take a look at the [documentation](https://rcmt.readthedocs.io/) to learn more.

## Development

```shell
# Install dependencies and dev-dependencies
poetry install
# Run linters
make lint
# Run tests
make test
# Generate and open the documentation
make docs
open ./docs/_build/html/index.html
```
